from kubernetes import client, config
from kubernetes.client import configuration
import time

def get_pod_metrics():
    configuration.assert_hostname = False
    config.load_kube_config()  # Load Kubernetes configuration from default location
    configuration.assert_hostname = False
    api_instance = client.CustomObjectsApi()

    # Retrieve metrics of all pods in the "default" namespace
    pods_metrics = api_instance.list_namespaced_custom_object(
        group="metrics.k8s.io",
        version="v1beta1",
        namespace="default",
        plural="pods"
    )

    pod_metrics_info = []
    for pod in pods_metrics["items"]:
        pod_name = pod["metadata"]["name"]
        cpu_usage = pod["containers"][0]["usage"]["cpu"]
        memory_usage = pod["containers"][0]["usage"]["memory"]
        pod_metrics_info.append((pod_name, cpu_usage, memory_usage))

    return pod_metrics_info

def display_dashboard(pod_metrics_info):
    print("Pod Name\t\tCPU Usage\tMemory Usage")
    print("---------------------------------------------")
    for pod_name, cpu_usage, memory_usage in pod_metrics_info:
        print(f"{pod_name}\t\t{cpu_usage}\t\t{memory_usage}")

def main():
    try:
        while True:
            pod_metrics_info = get_pod_metrics()
            display_dashboard(pod_metrics_info)
            time.sleep(10)  # Wait for 10 seconds before refreshing
    except KeyboardInterrupt:
        print("\nMonitoring stopped.")

if __name__ == "__main__":
    main()

